@@ -7,6 +7,7 @@ from django.utils.safestring import mark_safe
 
 from bson.objectid import ObjectId
 from mongoengine import Document
+from mongoengine.fields import URLField
 
 register = template.Library()
 
@@ -17,6 +18,9 @@ def get_document_value(document, key):
     if isinstance(value, ObjectId):
         return value
 
+    if isinstance(document._fields.get(key), URLField):
+        return mark_safe("""<a href="{0}">{1}</a>""".format(value, value))
+
     if isinstance(value, Document):
         app_label = value.__module__.replace(".models", "")
         document_name = value._class_name
