@@ -24,6 +24,7 @@ class IndexView(MongonautViewMixin, ListView):
 
     template_name = "mongonaut/index.html"
     queryset = []
+    permission = 'has_view_permission'
 
     def get_queryset(self):
         return self.get_mongoadmins()
@@ -76,10 +77,13 @@ class DocumentListView(MongonautViewMixin, FormView):
         self.document = getattr(self.models, self.document_name)
         queryset = self.document.objects.all()
 
+        if self.mongoadmin.ordering:
+            queryset = queryset.order_by(*self.mongoadmin.ordering)
+
         # search. move this to get_queryset
         # search. move this to get_queryset
         q = self.request.GET.get('q')
-        self.get_qset(queryset, q)
+        queryset = self.get_qset(queryset, q)
 
         ### Start pagination
         ### Note:
@@ -151,7 +155,7 @@ class DocumentListView(MongonautViewMixin, FormView):
             context['keys'] = ['id', ]
 
             # Show those items for which we've got list_fields on the mongoadmin
-            for key in [x for x in self.document._fields.keys() if x != 'id' and x in self.mongoadmin.list_fields]:
+            for key in [x for x in self.mongoadmin.list_fields if x != 'id' and x in self.document._fields.keys()]:
 
                 # TODO - Figure out why this EmbeddedDocumentField and ListField breaks this view
                 # Note - This is the challenge part, right? :)
